from typing import Any

def cos(*args, **kwargs) -> Any: ...

e: float

def exp(*args, **kwargs) -> Any: ...
def log(*args, **kwargs) -> Any: ...
def log10(*args, **kwargs) -> Any: ...
def phase(*args, **kwargs) -> Any: ...

pi: float

def polar(*args, **kwargs) -> Any: ...
def rect(*args, **kwargs) -> Any: ...
def sin(*args, **kwargs) -> Any: ...
def sqrt(*args, **kwargs) -> Any: ...
