"""
Module: 'struct' on micropython-v1.18-pyboard
"""
# MCU: {'ver': 'v1.18', 'port': 'pyboard', 'arch': 'armv7emsp', 'sysname': 'pyboard', 'release': '1.18.0', 'name': 'micropython', 'mpy': 7685, 'version': '1.18.0', 'machine': 'PYBv1.1 with STM32F405RG', 'build': '', 'nodename': 'pyboard', 'platform': 'pyboard', 'family': 'micropython'}
# Stubber: 1.5.4
from typing import Any


def calcsize(*args, **kwargs) -> Any:
    ...


def pack(*args, **kwargs) -> Any:
    ...


def pack_into(*args, **kwargs) -> Any:
    ...


def unpack(*args, **kwargs) -> Any:
    ...


def unpack_from(*args, **kwargs) -> Any:
    ...
