from typing import Any

class FrameBuffer:
    def __init__(self, *argv, **kwargs) -> None: ...
    def blit(self, *args, **kwargs) -> Any: ...
    def fill(self, *args, **kwargs) -> Any: ...
    def fill_rect(self, *args, **kwargs) -> Any: ...
    def hline(self, *args, **kwargs) -> Any: ...
    def line(self, *args, **kwargs) -> Any: ...
    def pixel(self, *args, **kwargs) -> Any: ...
    def rect(self, *args, **kwargs) -> Any: ...
    def scroll(self, *args, **kwargs) -> Any: ...
    def text(self, *args, **kwargs) -> Any: ...
    def vline(self, *args, **kwargs) -> Any: ...

def FrameBuffer1(*args, **kwargs) -> Any: ...

GS2_HMSB: int
GS4_HMSB: int
GS8: int
MONO_HLSB: int
MONO_HMSB: int
MONO_VLSB: int
MVLSB: int
RGB565: int
