from typing import Any

def a2b_base64(*args, **kwargs) -> Any: ...
def b2a_base64(*args, **kwargs) -> Any: ...
def crc32(*args, **kwargs) -> Any: ...
def hexlify(*args, **kwargs) -> Any: ...
def unhexlify(*args, **kwargs) -> Any: ...
