from typing import Any

def main(*args, **kwargs) -> Any: ...
def stop(*args, **kwargs) -> Any: ...

SD: Any

class DAC:
    def __init__(self, *argv, **kwargs) -> None: ...
    def write(self, *args, **kwargs) -> Any: ...
    CIRCULAR: int
    NORMAL: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def noise(self, *args, **kwargs) -> Any: ...
    def triangle(self, *args, **kwargs) -> Any: ...
    def write_timed(self, *args, **kwargs) -> Any: ...

class RTC:
    def __init__(self, *argv, **kwargs) -> None: ...
    def calibration(self, *args, **kwargs) -> Any: ...
    def datetime(self, *args, **kwargs) -> Any: ...
    def info(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def wakeup(self, *args, **kwargs) -> Any: ...

class ADC:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read(self, *args, **kwargs) -> Any: ...
    def read_timed(self, *args, **kwargs) -> Any: ...
    def read_timed_multi(self, *args, **kwargs) -> Any: ...

class ADCAll:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read_channel(self, *args, **kwargs) -> Any: ...
    def read_core_temp(self, *args, **kwargs) -> Any: ...
    def read_core_vbat(self, *args, **kwargs) -> Any: ...
    def read_core_vref(self, *args, **kwargs) -> Any: ...
    def read_vref(self, *args, **kwargs) -> Any: ...

class Accel:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def filtered_xyz(self, *args, **kwargs) -> Any: ...
    def tilt(self, *args, **kwargs) -> Any: ...
    def x(self, *args, **kwargs) -> Any: ...
    def y(self, *args, **kwargs) -> Any: ...
    def z(self, *args, **kwargs) -> Any: ...

class CAN:
    def __init__(self, *argv, **kwargs) -> None: ...
    def any(self, *args, **kwargs) -> Any: ...
    def send(self, *args, **kwargs) -> Any: ...
    BUS_OFF: int
    ERROR_ACTIVE: int
    ERROR_PASSIVE: int
    ERROR_WARNING: int
    LIST16: int
    LIST32: int
    LOOPBACK: int
    MASK16: int
    MASK32: int
    NORMAL: int
    SILENT: int
    SILENT_LOOPBACK: int
    STOPPED: int
    def clearfilter(self, *args, **kwargs) -> Any: ...
    def deinit(self, *args, **kwargs) -> Any: ...
    def info(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    @classmethod
    def initfilterbanks(cls, *args, **kwargs) -> Any: ...
    def recv(self, *args, **kwargs) -> Any: ...
    def restart(self, *args, **kwargs) -> Any: ...
    def rxcallback(self, *args, **kwargs) -> Any: ...
    def setfilter(self, *args, **kwargs) -> Any: ...
    def state(self, *args, **kwargs) -> Any: ...

class ExtInt:
    def __init__(self, *argv, **kwargs) -> None: ...
    EVT_FALLING: int
    EVT_RISING: int
    EVT_RISING_FALLING: int
    IRQ_FALLING: int
    IRQ_RISING: int
    IRQ_RISING_FALLING: int
    def disable(self, *args, **kwargs) -> Any: ...
    def enable(self, *args, **kwargs) -> Any: ...
    def line(self, *args, **kwargs) -> Any: ...
    def regs(self, *args, **kwargs) -> Any: ...
    def swint(self, *args, **kwargs) -> Any: ...

class Flash:
    def __init__(self, *argv, **kwargs) -> None: ...
    def ioctl(self, *args, **kwargs) -> Any: ...
    def readblocks(self, *args, **kwargs) -> Any: ...
    def writeblocks(self, *args, **kwargs) -> Any: ...

class I2C:
    def __init__(self, *argv, **kwargs) -> None: ...
    def send(self, *args, **kwargs) -> Any: ...
    CONTROLLER: int
    MASTER: int
    PERIPHERAL: int
    SLAVE: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def is_ready(self, *args, **kwargs) -> Any: ...
    def mem_read(self, *args, **kwargs) -> Any: ...
    def mem_write(self, *args, **kwargs) -> Any: ...
    def recv(self, *args, **kwargs) -> Any: ...
    def scan(self, *args, **kwargs) -> Any: ...

class LCD:
    def __init__(self, *argv, **kwargs) -> None: ...
    def get(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def command(self, *args, **kwargs) -> Any: ...
    def contrast(self, *args, **kwargs) -> Any: ...
    def fill(self, *args, **kwargs) -> Any: ...
    def light(self, *args, **kwargs) -> Any: ...
    def pixel(self, *args, **kwargs) -> Any: ...
    def show(self, *args, **kwargs) -> Any: ...
    def text(self, *args, **kwargs) -> Any: ...

class LED:
    def __init__(self, *argv, **kwargs) -> None: ...
    def intensity(self, *args, **kwargs) -> Any: ...
    def off(self, *args, **kwargs) -> Any: ...
    def on(self, *args, **kwargs) -> Any: ...
    def toggle(self, *args, **kwargs) -> Any: ...

class Pin:
    def __init__(self, *argv, **kwargs) -> None: ...
    @classmethod
    def dict(cls, *args, **kwargs) -> Any: ...
    def value(self, *args, **kwargs) -> Any: ...
    AF1_TIM1: int
    AF1_TIM2: int
    AF2_TIM3: int
    AF2_TIM4: int
    AF2_TIM5: int
    AF3_TIM10: int
    AF3_TIM11: int
    AF3_TIM8: int
    AF3_TIM9: int
    AF4_I2C1: int
    AF4_I2C2: int
    AF5_I2S2: int
    AF5_SPI1: int
    AF5_SPI2: int
    AF6_I2S2: int
    AF7_USART1: int
    AF7_USART2: int
    AF7_USART3: int
    AF8_UART4: int
    AF8_USART6: int
    AF9_CAN1: int
    AF9_CAN2: int
    AF9_TIM12: int
    AF9_TIM13: int
    AF9_TIM14: int
    AF_OD: int
    AF_PP: int
    ALT: int
    ALT_OPEN_DRAIN: int
    ANALOG: int
    IN: int
    IRQ_FALLING: int
    IRQ_RISING: int
    OPEN_DRAIN: int
    OUT: int
    OUT_OD: int
    OUT_PP: int
    PULL_DOWN: int
    PULL_NONE: int
    PULL_UP: int
    def af(self, *args, **kwargs) -> Any: ...
    def af_list(self, *args, **kwargs) -> Any: ...
    class board:
        def __init__(self, *argv, **kwargs) -> None: ...
        LED_BLUE: Any
        LED_GREEN: Any
        LED_RED: Any
        LED_YELLOW: Any
        MMA_AVDD: Any
        MMA_INT: Any
        SD: Any
        SD_CK: Any
        SD_CMD: Any
        SD_D0: Any
        SD_D1: Any
        SD_D2: Any
        SD_D3: Any
        SD_SW: Any
        SW: Any
        USB_DM: Any
        USB_DP: Any
        USB_ID: Any
        USB_VBUS: Any
        X1: Any
        X10: Any
        X11: Any
        X12: Any
        X17: Any
        X18: Any
        X19: Any
        X2: Any
        X20: Any
        X21: Any
        X22: Any
        X3: Any
        X4: Any
        X5: Any
        X6: Any
        X7: Any
        X8: Any
        X9: Any
        Y1: Any
        Y10: Any
        Y11: Any
        Y12: Any
        Y2: Any
        Y3: Any
        Y4: Any
        Y5: Any
        Y6: Any
        Y7: Any
        Y8: Any
        Y9: Any
    class cpu:
        def __init__(self, *argv, **kwargs) -> None: ...
        A0: Any
        A1: Any
        A10: Any
        A11: Any
        A12: Any
        A13: Any
        A14: Any
        A15: Any
        A2: Any
        A3: Any
        A4: Any
        A5: Any
        A6: Any
        A7: Any
        A8: Any
        A9: Any
        B0: Any
        B1: Any
        B10: Any
        B11: Any
        B12: Any
        B13: Any
        B14: Any
        B15: Any
        B2: Any
        B3: Any
        B4: Any
        B5: Any
        B6: Any
        B7: Any
        B8: Any
        B9: Any
        C0: Any
        C1: Any
        C10: Any
        C11: Any
        C12: Any
        C13: Any
        C2: Any
        C3: Any
        C4: Any
        C5: Any
        C6: Any
        C7: Any
        C8: Any
        C9: Any
        D2: Any
    @classmethod
    def debug(cls, *args, **kwargs) -> Any: ...
    def gpio(self, *args, **kwargs) -> Any: ...
    def high(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def irq(self, *args, **kwargs) -> Any: ...
    def low(self, *args, **kwargs) -> Any: ...
    @classmethod
    def mapper(cls, *args, **kwargs) -> Any: ...
    def mode(self, *args, **kwargs) -> Any: ...
    def name(self, *args, **kwargs) -> Any: ...
    def names(self, *args, **kwargs) -> Any: ...
    def off(self, *args, **kwargs) -> Any: ...
    def on(self, *args, **kwargs) -> Any: ...
    def pin(self, *args, **kwargs) -> Any: ...
    def port(self, *args, **kwargs) -> Any: ...
    def pull(self, *args, **kwargs) -> Any: ...

class SDCard:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def info(self, *args, **kwargs) -> Any: ...
    def ioctl(self, *args, **kwargs) -> Any: ...
    def power(self, *args, **kwargs) -> Any: ...
    def present(self, *args, **kwargs) -> Any: ...
    def readblocks(self, *args, **kwargs) -> Any: ...
    def writeblocks(self, *args, **kwargs) -> Any: ...

class SPI:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def send(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    CONTROLLER: int
    LSB: int
    MASTER: int
    MSB: int
    PERIPHERAL: int
    SLAVE: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def recv(self, *args, **kwargs) -> Any: ...
    def send_recv(self, *args, **kwargs) -> Any: ...
    def write_readinto(self, *args, **kwargs) -> Any: ...

class Servo:
    def __init__(self, *argv, **kwargs) -> None: ...
    def angle(self, *args, **kwargs) -> Any: ...
    def calibration(self, *args, **kwargs) -> Any: ...
    def pulse_width(self, *args, **kwargs) -> Any: ...
    def speed(self, *args, **kwargs) -> Any: ...

class Switch:
    def __init__(self, *argv, **kwargs) -> None: ...
    def value(self, *args, **kwargs) -> Any: ...
    def callback(self, *args, **kwargs) -> Any: ...

class Timer:
    def __init__(self, *argv, **kwargs) -> None: ...
    BOTH: int
    BRK_HIGH: int
    BRK_LOW: int
    BRK_OFF: int
    CENTER: int
    DOWN: int
    ENC_A: int
    ENC_AB: int
    ENC_B: int
    FALLING: int
    HIGH: int
    IC: int
    LOW: int
    OC_ACTIVE: int
    OC_FORCED_ACTIVE: int
    OC_FORCED_INACTIVE: int
    OC_INACTIVE: int
    OC_TIMING: int
    OC_TOGGLE: int
    PWM: int
    PWM_INVERTED: int
    RISING: int
    UP: int
    def callback(self, *args, **kwargs) -> Any: ...
    def channel(self, *args, **kwargs) -> Any: ...
    def counter(self, *args, **kwargs) -> Any: ...
    def deinit(self, *args, **kwargs) -> Any: ...
    def freq(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def period(self, *args, **kwargs) -> Any: ...
    def prescaler(self, *args, **kwargs) -> Any: ...
    def source_freq(self, *args, **kwargs) -> Any: ...

class UART:
    def __init__(self, *argv, **kwargs) -> None: ...
    def any(self, *args, **kwargs) -> Any: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def readline(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    CTS: int
    IRQ_RXIDLE: int
    RTS: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def irq(self, *args, **kwargs) -> Any: ...
    def readchar(self, *args, **kwargs) -> Any: ...
    def sendbreak(self, *args, **kwargs) -> Any: ...
    def writechar(self, *args, **kwargs) -> Any: ...

class USB_HID:
    def __init__(self, *argv, **kwargs) -> None: ...
    def send(self, *args, **kwargs) -> Any: ...
    def recv(self, *args, **kwargs) -> Any: ...

class USB_VCP:
    def __init__(self, *argv, **kwargs) -> None: ...
    def any(self, *args, **kwargs) -> Any: ...
    def close(self, *args, **kwargs) -> Any: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def readline(self, *args, **kwargs) -> Any: ...
    def send(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    CTS: int
    IRQ_RX: int
    RTS: int
    def init(self, *args, **kwargs) -> Any: ...
    def irq(self, *args, **kwargs) -> Any: ...
    def isconnected(self, *args, **kwargs) -> Any: ...
    def readlines(self, *args, **kwargs) -> Any: ...
    def recv(self, *args, **kwargs) -> Any: ...
    def setinterrupt(self, *args, **kwargs) -> Any: ...

def bootloader(*args, **kwargs) -> Any: ...
def country(*args, **kwargs) -> Any: ...
def delay(*args, **kwargs) -> Any: ...
def dht_readinto(*args, **kwargs) -> Any: ...
def disable_irq(*args, **kwargs) -> Any: ...
def elapsed_micros(*args, **kwargs) -> Any: ...
def elapsed_millis(*args, **kwargs) -> Any: ...
def enable_irq(*args, **kwargs) -> Any: ...
def fault_debug(*args, **kwargs) -> Any: ...
def freq(*args, **kwargs) -> Any: ...
def hard_reset(*args, **kwargs) -> Any: ...
def have_cdc(*args, **kwargs) -> Any: ...
def hid(*args, **kwargs) -> Any: ...

hid_keyboard: tuple
hid_mouse: tuple

def info(*args, **kwargs) -> Any: ...
def micros(*args, **kwargs) -> Any: ...
def millis(*args, **kwargs) -> Any: ...
def mount(*args, **kwargs) -> Any: ...
def pwm(*args, **kwargs) -> Any: ...
def repl_info(*args, **kwargs) -> Any: ...
def repl_uart(*args, **kwargs) -> Any: ...
def rng(*args, **kwargs) -> Any: ...
def servo(*args, **kwargs) -> Any: ...
def standby(*args, **kwargs) -> Any: ...
def sync(*args, **kwargs) -> Any: ...
def udelay(*args, **kwargs) -> Any: ...
def unique_id(*args, **kwargs) -> Any: ...
def usb_mode(*args, **kwargs) -> Any: ...
def wfi(*args, **kwargs) -> Any: ...
