from typing import Any

def choice(*args, **kwargs) -> Any: ...
def getrandbits(*args, **kwargs) -> Any: ...
def randint(*args, **kwargs) -> Any: ...
def random(*args, **kwargs) -> Any: ...
def randrange(*args, **kwargs) -> Any: ...
def seed(*args, **kwargs) -> Any: ...
def uniform(*args, **kwargs) -> Any: ...
